@@ -5,7 +5,7 @@
 package Lingua::Interset::Tagset::MUL::Upos;
 use strict;
 use warnings;
-our $VERSION = '3.010';
+our $VERSION = '3.011';
 
 use utf8;
 use open ':utf8';
@@ -96,7 +96,10 @@ around BUILDARGS => sub
                    'adp'  => 'ADP',
                    'conj' => { 'conjtype' => { 'sub' => 'SCONJ',
                                                '@'   => 'CCONJ' }},
-                   'part' => 'PART',
+                   # Make sure that RP particles from the Penn Treebank and separable verb prefixes from German STTS
+                   # do not end up as PART; UD clearly documents that they should be ADP or ADV.
+                   'part' => { 'parttype' => { 'vbp' => 'ADP',
+                                               '@'   => 'PART' }},
                    'int'  => 'INTJ',
                    'punc' => 'PUNCT',
                    'sym'  => 'SYM',
@@ -157,7 +160,7 @@ Lingua::Interset::Tagset::MUL::Upos - Driver for the Universal Part-of-Speech Ta
 
 =head1 VERSION
 
-version 3.010
+version 3.011
 
 =head1 SYNOPSIS
 
